@@ -243,6 +243,33 @@ class IsRightQuotaEn(SpecialCondition):
         return False
 
 
+class DialogueIsGreaterThanEN(SpecialCondition, ABC):
+    def __init__(self, SYMBOLS: dict, length: int):
+        super(DialogueIsGreaterThanEN, self).__init__('DialogueIsGreaterThanEN', SYMBOLS)
+        self.length = length
+        self.word_pattern = re.compile('^[a-zA-Z0-9]+')
+
+    def accept(self, state: EnSequence) -> bool:
+        if state.v_pointer < self.length:
+            return False
+        i = state.v_pointer
+        n_quota = 0
+        n_word = 0
+        out = True
+        while i >= 0:
+            if self.symbols['all_quota'].match(state[i]):
+                n_quota += 1
+            if n_quota >= 2:
+                out = False
+            if self.word_pattern.match(state[i]):
+                n_word += 1
+                if n_word >= self.length:
+                    break
+            i -= 1
+
+        return out
+
+
 class IsListQuotaEN(SpecialCondition):
     def __init__(self, index=0):
         super(IsListQuotaEN, self).__init__('IsListQuotaEN', SYMBOLS)
@@ -325,7 +352,7 @@ class NotInWhitelistDotEn(SpecialCondition):
         self.white_list = [pattern.sub('', v.strip()) for v in white_list.splitlines()]
 
     def accept(self, state: EnSequence) -> bool:
-        if not state.current_value == '.':
+        if not state.current_value in ['.', '!']:
             return True
         else:
             for word in self.white_list:
@@ -352,6 +379,6 @@ class NotInWhitelistDotEn(SpecialCondition):
 
     def find_dot(self, str_list: List[str], start=0):
         for i, v in enumerate(str_list[start::]):
-            if v == '.':
+            if v in ['.', '!']:
                 return i + start
         return -1
