@@ -154,7 +154,7 @@ class LongHandlerEN(Operation):
         self.get_init_quota_bracket(state)
         cut_id, dialog_success = self.dialog_handler(temps_state)
         if dialog_success:
-            state.v_pointer = min(cut_id, state.length-1)
+            state.v_pointer = min(cut_id, state.length - 1)
             state.add_to_sentence_list()
             state.quota_en = temps_state.quota_en
             state.bracket_left = temps_state.bracket_left
@@ -164,7 +164,7 @@ class LongHandlerEN(Operation):
         else:
             cut_id, comma_success = self.comma_weights(temps_state)
             if comma_success:
-                state.v_pointer = min(cut_id, state.length-1)
+                state.v_pointer = min(cut_id, state.length - 1)
                 state.add_to_sentence_list()
                 state.quota_en = temps_state.quota_en
                 state.bracket_left = temps_state.bracket_left
@@ -195,7 +195,8 @@ class LongHandlerEN(Operation):
                 continue
             if not self.space.match(state.current_value):
                 sub_len += 1
-            if state.current_value in [':', '：'] and sub_len > self.min_sentence_length and self.blank.match(state[i + 1][0]):
+            if state.current_value in [':', '：'] and sub_len > self.min_sentence_length and self.blank.match(
+                    state[i + 1][0]):
                 return i, True
             if state.current_value == ',' and not state.next_value.isdigit():
                 # -- 首字母大写优先切分 -- #
@@ -203,16 +204,16 @@ class LongHandlerEN(Operation):
                     best_i = i
                     max_score = 10
                     best_sub_len = sub_len
-                elif self.symbols['all_quota'].match(state[min(i + 1, state.length-1)]):
+                elif self.symbols['all_quota'].match(state[min(i + 1, state.length - 1)]):
                     weight = 0.5 + 1 - abs(idx - half_len) / half_len
                     if weight > max_score:
-                        best_i = min(i + 1, state.length-1)
+                        best_i = min(i + 1, state.length - 1)
                         max_score = weight
                         best_sub_len = sub_len
                 else:
                     # -- 在权重层里寻找合理的切句位置 -- #
                     for n_words in range(self.max_key_size):
-                        key = ' '.join([state[min(i + ii * 2, state.length-1)].lower() for ii in range(n_words + 2)])
+                        key = ' '.join([state[min(i + ii * 2, state.length - 1)].lower() for ii in range(n_words + 2)])
                         postion_penalty = 1 - abs(idx - half_len) / half_len
                         weight = self.weights.get(key, 5) / 10 + postion_penalty
                         # weight = postion_penalty
@@ -230,7 +231,7 @@ class LongHandlerEN(Operation):
         sub_len = self.min_sentence_length
         state.quota_en = abs(state.quota_en - self.quota_en)
         state.quota_left = abs(state.quota_left - self.quota_left)
-        state.bracket_right = abs(state.bracket_right-self.bracket_right)
+        state.bracket_right = abs(state.bracket_right - self.bracket_right)
         state.bracket_left = abs(state.bracket_left - self.bracket_left)
         for i in range(state.sentence_start + self.min_sentence_length * 2 - 1, org_pointer):
             state.v_pointer = i
@@ -248,7 +249,7 @@ class LongHandlerEN(Operation):
 
             if self.is_right_quota(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state):
                 state.v_pointer = org_pointer
-                return min(i + 1, state.length-1), True
+                return min(i + 1, state.length - 1), True
         else:
             state.v_pointer = org_pointer
             return -1, False
@@ -256,7 +257,7 @@ class LongHandlerEN(Operation):
     def get_init_quota_bracket(self, state: EnSequence):
         org_pointer = state.v_pointer
         start = state.sentence_start if self.pre_sentence_start != state.sentence_start else self.pre_index
-        for i in range(start, org_pointer):
+        for i in range(start, org_pointer + 1):
             if self.symbols['all_quota'].match(state[i]):
                 if self.symbols['quotation_left'].match(state[i]):
                     self.quota_left += 1
@@ -268,12 +269,11 @@ class LongHandlerEN(Operation):
             if self.symbols['bracket_left'].match(state[i]):
                 self.bracket_left += 1
             if self.symbols['bracket_right'].match(state[i]):
-               self.bracket_right += 1
-        #self.pre_index = org_pointer
+                self.bracket_right += 1
+        # self.pre_index = org_pointer
         self.pre_sentence_start = state.sentence_start
 
 
-
 class EndState(Operation):
     def __init__(self, symbols: dict, name=None):
         super(EndState, self).__init__('EndState' if not name else name, symbols)
