@@ -202,4 +202,6 @@ U.S.A.
 viz.
 vol.
 yr.
+G.L.O.W.
+U!S!A!
 """
\ No newline at end of file
